==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionChangedEventArgsDescription } from "./PropertyEditorPropertyDescriptionChangedEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("NewValue", "Unknown");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.b(a);
            a.ad("PropertyEditorPropertyDescriptionChangedEventArgs", () => new PropertyEditorPropertyDescriptionChangedEventArgsDescription());
            a.ac("PropertyEditorPropertyDescriptionChangedEventArgs", PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionChangedEventArgsDescription } from "./PropertyEditorPropertyDescriptionChangedEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("NewValue", "Unknown");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.b(a);
            a.ae("PropertyEditorPropertyDescriptionChangedEventArgs", () => new PropertyEditorPropertyDescriptionChangedEventArgsDescription());
            a.ad("PropertyEditorPropertyDescriptionChangedEventArgs", PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata;
})();
